aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPDBActionCommons.h
diff options
context:
space:
mode:
authorstuconnolly <stuart02@gmail.com>2012-03-18 20:05:36 +0000
committerstuconnolly <stuart02@gmail.com>2012-03-18 20:05:36 +0000
commit524e8c356b4074f5be5933b0551374a130a8f6d1 (patch)
tree0dab40735f2d9484930050cd08376cbf15e4ea55 /Source/SPDBActionCommons.h
parentbe3263f8158cb6f3dfa1005f49beefa7e494b852 (diff)
downloadsequelpro-524e8c356b4074f5be5933b0551374a130a8f6d1.tar.gz
sequelpro-524e8c356b4074f5be5933b0551374a130a8f6d1.tar.bz2
sequelpro-524e8c356b4074f5be5933b0551374a130a8f6d1.zip
Bring outline view branch up to date with trunk (r3471:r3517).
Diffstat (limited to 'Source/SPDBActionCommons.h')
-rw-r--r--Source/SPDBActionCommons.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/Source/SPDBActionCommons.h b/Source/SPDBActionCommons.h
index 6ff6e11c..7ae7ec79 100644
--- a/Source/SPDBActionCommons.h
+++ b/Source/SPDBActionCommons.h
@@ -22,18 +22,18 @@
//
// More info at <http://code.google.com/p/sequel-pro/>
-#import <MCPKit/MCPKit.h>
+@class SPMySQLConnection;
@interface SPDBActionCommons : NSObject
{
- MCPConnection *connection;
+ SPMySQLConnection *connection;
NSWindow *messageWindow;
}
/**
* @property connection References the MCPKit connection to MySQL; it has to be set.
*/
-@property (retain) MCPConnection *connection;
+@property (retain) SPMySQLConnection *connection;
/**
* @property messageWindow The NSWindow instance to send message sheets to.
@@ -22,18 +22,18 @@
}
/**
- * @property connection References the MCPKit connection to MySQL; it has to be set.
+ * @property connection References the SPMySQL.framework MySQL connection; it has to be set.
*/